url

package
v0.0.0-...-74e38f5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: MIT Imports: 7 Imported by: 1

Documentation

Index

Constants

const StructTag = "url_values"

Variables

This section is empty.

Functions

func SortQueryString

func SortQueryString(query string) (string, error)

func SortedQueryString

func SortedQueryString(vals url.Values) string

func SortedUrlValues

func SortedUrlValues(vals url.Values) (sortedKeys []string, sortedKeyValues map[string][]string)

Types

type Values

type Values struct {
	url.Values
}

Values wraps the standard go library's url.Values to add a Marshal method which uses reflection to easily add each unignored field as a query parameter.

func (*Values) Marshal

func (v *Values) Marshal(values interface{}) (err error)

Jump to